<?php

namespace Drupal\url_status_scanner\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * This form is used to display the settings for the URL Status Scanner module.
 */
class UrlStatusScannerSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'url_status_scanner_settings';
  }

  /**
   * {@inheritdoc}
   *
   * @return string[]
   *   An array of editable configuration names.
   */
  protected function getEditableConfigNames(): array {
    return [
      'url_status_scanner.settings',
    ];
  }

  /**
   * {@inheritdoc}
   *
   * @param array<string, mixed> $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array<string, mixed>
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('url_status_scanner.settings');

    $form['intro'] = [
      '#type' => 'html_tag',
      '#tag' => 'p',
      '#value' => $this->t('The URL Status Scanner module helps track the status of external URLs.'),
    ];

    $form['url_status_scanner_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('URL Status Scanner Settings'),
      '#description' => $this->t('Select which locations do you want to scan for URLs. Those URLs will be tracked, and their status will be shown in the dashboard.'),
    ];

    $form['url_status_scanner_settings']['basecode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Base code'),
      '#description' => $this->t('Scan in base code files like custom modules and themes for URLs.'),
      '#default_value' => $config->get('scan_basecode'),
    ];

    $form['url_status_scanner_settings']['config'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Config objects'),
      '#description' => $this->t('Scan in config objects.'),
      '#default_value' => $config->get('scan_in_config'),
    ];

    $form['url_status_scanner_settings']['content'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Content'),
      '#description' => $this->t('Scan in content entities like nodes. <strong>Warning:</strong> This can take a long time for large sites!'),
      '#default_value' => $config->get('scan_in_content'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   *
   * @param array<string, mixed> $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return void
   *   This method does not return anything.
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('url_status_scanner.settings')
      ->set('scan_basecode', $form_state->getValue('basecode'))
      ->set('scan_in_config', $form_state->getValue('config'))
      ->set('scan_in_content', $form_state->getValue('content'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
